FetchOperation class

Fetch operation

Constructors

FetchOperation(GitRepository repo)

Properties

hashCode int
The hash code for this object.
no setterinherited
remoteManager RemoteManager
final
repo GitRepository
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetch(String remoteName, {Credentials? credentials, List<String>? refspecs}) Future<FetchResult>
Fetch from remote
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited