Remote class

Remote repository configuration

Constructors

Remote({required String name, required String url, String? pushUrl})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isHttps bool
Check if this is an HTTPS remote
no setter
isSsh bool
Check if this is an SSH remote
no setter
name String
final
pushUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited