RepositoryStatus class

Repository status

Constructors

RepositoryStatus({required List<StatusEntry> staged, required List<StatusEntry> unstaged, required List<StatusEntry> untracked, String? currentBranch, String? currentCommit})
const

Properties

currentBranch String?
final
currentCommit String?
final
hashCode int
The hash code for this object.
no setterinherited
isClean bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staged List<StatusEntry>
final
unstaged List<StatusEntry>
final
untracked List<StatusEntry>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited