GitObject class abstract
Base class for all git objects
Properties
- hash → String
-
SHA-1 hash of this object (40 hex chars)
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → GitObjectType
-
Type of git object
no setter
Methods
-
getContentWithHeader(
) → Uint8List - Get the full content with header for hashing Format: "
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List - Serialize object to bytes (without header)
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override